<?php
namespace SVIApp;

/**
 * Frontend Pages Handler
 */
class Frontend
{

    public function __construct()
    {
        $this->options = $this->parseOptions(get_option('woosvi_options', []));
        $this->activated = array_key_exists('default', $this->options) ? $this->options['default'] : false;
        if (!$this->activated) { //Check if SVI is enabled
            return;
        }

        $this->suffix = defined('SCRIPT_DEBUG') && SCRIPT_DEBUG ? '' : '.min';
        $this->theme = wp_get_theme();
        if (!is_admin()) {
            add_action('woocommerce_before_single_product', [$this, 'remove_hooks'], 20);
            add_action('wp_enqueue_scripts', array($this, 'load_scripts'), 20, 1);
            add_action('woocommerce_before_single_product_summary', [$this, 'render_frontend'], 20);
            add_filter('wc_get_template', [$this, 'filter_wc_get_template'], 1, 5);

            if (array_key_exists('variation_thumbnails', $this->options) && $this->options['variation_thumbnails']) {
                add_action('woocommerce_single_variation', [$this, 'render_before_add_to_cart_button'], 5);
            }
            if (svi_fs()->can_use_premium_code__premium_only()) {

                if (array_key_exists('svicart', $this->options) && $this->options['svicart']) {
                    add_filter('woocommerce_cart_item_thumbnail', [$this, 'filter_woocommerce_cart_item_thumbnail__premium_only'], 150, 3);
                }

                if (array_key_exists('sviemail', $this->options) && $this->options['sviemail']) {
                    add_filter('woocommerce_email_order_items_args', [$this, 'filter_add_images_woocommerce_emails__premium_only'], 10, 1);
                    add_filter('woocommerce_order_item_thumbnail', [$this, 'filter_woocommerce_order_item_thumbnail__premium_only'], 10, 2);
                }
            }
        }
    }

    public function filter_wc_get_template($located, $template_name, $args, $template_path, $default_path)
    {
        // make filter magic happen here...
        global $post;

        if (!isset($post->ID)) {
            return $located;
        }

        $run = get_post_meta($post->ID, '_checkbox_svipro_enabled', true);

        if ($template_name == 'single-product/product-image.php' && $run != 'yes') {
            return $this->render_frontend();
        } else {
            return $located;
        }

    }

    public function parseOptions($args)
    {
        if (svi_fs()->can_use_premium_code__premium_only()) {
            $defaults = array(
                'imagecaption' => false,
                'imagecaption_option' => 'caption',
                'main_imagesize' => 'shop_single',
                'thumb_imagesize' => 'shop_thumbnail',
                'triger_match' => false,
                'sviforce_image' => false,
                'custom_class' => '',
                'preload_fimg' => false,
                'quick_view' => false,
                //LENS
                'lens' => false,
                'lens_mobiledisabled' => false,
                'lens_type' => 'round',
                'containlenszoom' => true,
                'lens_easing' => false,
                'lens_size' => 150,
                'lens_border' => false,
                'lens_lensBorder' => '',
                'lens_zoomtype' => 'lens',
                'lens_scrollzoom' => false,
                'lens_lensFadeIn' => false,
                'lens_zoomWindowFadeIn' => 200,
                'lens_zIndex' => 999,
                'lens_zoomWindowWidth' => 400,
                'lens_zoomWindowHeight' => 400,
                //LIGTHBOX
                'lightbox' => false,
                'variation_thumbnails_lb' => false,
                'lightbox_enabled' => 'main',
                'lightbox_icon' => false,
                'lightbox_iconclick' => false,
                'lightbox_iconcolor' => '#888',
                'lightbox_thumbnails' => false,
                'lightbox_close' => false,
                'lightbox_title' => false,
                'lightbox_fullScreen' => false,
                'lightbox_zoom' => false,
                'lightbox_share' => false,
                'lightbox_counter' => false,
                'lightbox_controls' => true,
                //Stacked
                'stacked' => false,
                'sticky' => false,
                'sticky_margin' => false,
                //SLIDER
                'slider' => false,
                'slider_center' => false,
                'slider_navigation' => false,
                'slider_navigation_thumb' => false,
                'slider_navcolor' => '',
                'slider_autoslide' => false,
                'slider_autoslide_ms' => 1000,
                'slider_spaceBetween' => '',
                'slider_spaceBetweenNavigation' => '',
                'slider_effect' => '',
                'slider_pagination' => false,
                'slider_paginationType' => '',
                'slider_paginationDynamicBullets' => '',
                'slider_paginationclickable' => false,
                'slider_pagination_color' => '',
                'slider_navigation_color' => '',
                //THUMBNAILS
                'disable_thumb' => false,
                'slider_position' => '0',
                'columns' => 4,
                'hide_thumbs' => false,
                'swselect' => false,
                'variation_swap' => false,
                'keep_thumbnails' => false,
                'keep_thumbnails_option' => false,
                'thumbnails_showactive' => false,
                //SUB THUMBNAILS
                'variation_thumbnails' => false,
                'columns_variations' => '5',
                'variation_thumbnails_validate' => true,
                //VIDEO
                'video_autoplay' => false,
                'video_loop' => false,
                'video_controls' => false,
                'video_mute' => false,
            );
        } else {
            $defaults = array(
                'main_imagesize' => 'shop_single',
                'thumb_imagesize' => 'shop_thumbnail',
                //LENS
                'lens' => false,
                'containlenszoom' => true,
                'lens_zoomtype' => 'lens',
                'lens_mobiledisabled' => false,
                'lens_zIndex' => 999,
                //LIGTHBOX
                'lightbox' => false,
                'variation_thumbnails_lb' => false,
                'lightbox_enabled' => 'main',
                'lightbox_icon' => false,
                'lightbox_close' => false,
                'lightbox_fullScreen' => false,
                'lightbox_zoom' => false,
                'lightbox_share' => false,
                'lightbox_counter' => false,
                'lightbox_controls' => true,
                //THUMBNAILS
                'columns' => 4,
                'hide_thumbs' => false,
                //SUB THUMBNAILS
                'variation_thumbnails' => false,
                'columns_variations' => '5',
            );
        }
        return wp_parse_args($args, $defaults);

    }

    public function parseGlobalData($pid = false)
    {
        global $post;
        $detect = new Mobile_Detect;

        if (svi_fs()->can_use_premium_code__premium_only()) {
            $has_product = false;

            if (is_product() || is_a($post, 'WP_Post') && has_shortcode($post->post_content, 'product_page') || shortcode_exists('product_page')) {
                $has_product = true;
            }

            if (!$this->options['lens_mobiledisabled'] && $detect->isMobile()) {
                $this->options['lens'] = false;
            }

            return array(
                'version' => SVI_VERSION,
                'rtl' => is_rtl(),
                'template' => $this->theme->template,
                'flatsome' => $this->theme->template == 'flatsome' ? 'has-hover' : false,
                'triger_match' => ($this->options['triger_match'] ? true : false),
                'imagecaption' => ($this->options['imagecaption'] ? $this->options['imagecaption_option'] : false),
                'imgClass' => ($this->options['sviforce_image'] ? true : false),
                'custom_class' => $this->options['custom_class'],
                'preload_fimg' => $this->options['preload_fimg'],
                'quick_view' => $this->options['quick_view'],

                //LENS
                'lens' => ($this->options['lens'] ? true : false),
                'lens_mobiledisabled' => $this->options['lens_mobiledisabled'] ? true : false,
                'lens_type' => $this->options['lens_type'] ? $this->options['lens_type'] : 'round',
                'lens_containlenszoom' => $this->options['containlenszoom'] ? false : true,
                'lens_easing' => $this->options['lens_easing'] ? true : false,
                'lens_size' => $this->options['lens_size'] ? $this->options['lens_size'] : 150,
                'lens_border' => $this->options['lens_border'] ? $this->options['lens_border'] : false,
                'lens_lensBorder' => $this->options['lens_border'] == 'transparent' ? 0 : $this->options['lens_lensBorder'],
                'lens_zoomtype' => $this->options['lens_zoomtype'] ? $this->options['lens_zoomtype'] : 'lens',
                'lens_scrollzoom' => $this->options['lens_scrollzoom'] ? true : false,
                'lens_lensFadeIn' => $this->options['lens_lensFadeIn'] ? isset($this->options['lens_lensFadeInms']) ? $this->options['lens_lensFadeInms'] : false : 200,
                'lens_zoomWindowFadeIn' => $this->options['lens_zoomWindowFadeIn'] ? $this->options['lens_zoomWindowFadeInms'] : 200,
                'lens_zIndex' => $this->options['lens_zIndex'] ? $this->options['lens_zIndex'] : 0,
                'lens_zoomWindowWidth' => $this->options['lens_zoomWindowWidth'] ? $this->options['lens_zoomWindowWidth'] : 400,
                'lens_zoomWindowHeight' => $this->options['lens_zoomWindowHeight'] ? $this->options['lens_zoomWindowHeight'] : 400,
                //LIGTHBOX
                'lightbox' => $this->options['lightbox'] ? true : false,
                'variation_thumbnails_lb' => $this->options['variation_thumbnails_lb'] ? true : false,
                'lightbox_enabled' => 'main',
                'lightbox_icon' => $this->options['lightbox_icon'] ? true : false,
                'lightbox_iconclick' => $this->options['lightbox_iconclick'] ? true : false,
                'lightbox_iconcolor' => $this->options['lightbox_iconcolor'] ? $this->options['lightbox_iconcolor'] : '#888',
                'lightbox_title' => $this->options['lightbox_title'] ? true : false,
                //'lightbox_download' => $this->options['lightbox_download'] ? true : false,
                'lightbox_share' => $this->options['lightbox_share'] ? true : false,
                'lightbox_close' => $this->options['lightbox_close'] ? true : false,
                'lightbox_controls' => $this->options['lightbox_controls'] ? true : false,
                //'lightbox_loop' => $this->options['lightbox_loop'] ? true : false,
                'lightbox_zoom' => $this->options['lightbox_zoom'] ? true : false,
                'lightbox_counter' => $this->options['lightbox_counter'] ? true : false,
                'lightbox_fullScreen' => $this->options['lightbox_fullScreen'] ? true : false,
                'lightbox_thumbnails' => $this->options['lightbox_thumbnails'] ? true : false,
                //Stacked
                'stacked' => $this->options['stacked'] ? true : false,
                'sticky' => $this->options['sticky'] ? true : false,
                'sticky_margin' => $this->options['sticky_margin'] > 10 ? $this->options['sticky_margin'] : 10,
                //SLIDER
                'slider' => $has_product ? ($this->options['slider'] ? true : false) : true,
                'slider_center' => ($this->options['slider_center'] ? true : false),
                'slider_navigation' => ($this->options['slider_navigation'] ? true : false),
                'slider_navigation_thumb' => ($this->options['slider_navigation_thumb'] ? true : false),
                'slider_navcolor' => $this->options['slider_navcolor'],
                'slider_autoslide' => ($this->options['slider_autoslide'] ? true : false),
                'slider_autoslide_ms' => $this->options['slider_autoslide_ms'],
                'slider_spaceBetween' => $this->options['slider_spaceBetween'],
                'slider_spaceBetweenNavigation' => $this->options['slider_spaceBetweenNavigation'],
                'slider_effect' => $this->options['slider_effect'],
                'slider_pagination' => $this->options['slider_pagination'] ? true : false,
                'slider_paginationType' => $this->options['slider_paginationType'],
                'slider_paginationDynamicBullets' => $this->options['slider_paginationDynamicBullets'],
                'slider_paginationclickable' => $this->options['slider_paginationclickable'] ? true : false,
                'slider_pagination_color' => $this->options['slider_pagination_color'] ? $this->options['slider_pagination_color'] : '#888',
                'slider_navigation_color' => $this->options['slider_navigation_color'] ? $this->options['slider_navigation_color'] : '#888',
                //THUMBNAILS
                'disable_thumb' => $has_product ? $this->options['disable_thumb'] ? true : false : true,
                'position' => $this->options['slider_position'],
                'columns' => $this->options['slider_position'] > 0 ? 1 : $this->options['columns'],
                'hidden_thumb' => $this->options['hide_thumbs'] ? true : false,
                'swselect' => $this->options['swselect'] ? true : false,
                'variation_swap' => $this->options['variation_swap'] ? true : false,
                'keep_thumbnails' => $this->options['keep_thumbnails'] ? true : false,
                'keep_thumbnails_option' => $this->options['keep_thumbnails_option'] ? $this->options['keep_thumbnails'] ? $this->options['keep_thumbnails_option'] : false : false,
                'thumbnails_showactive' => $this->options['thumbnails_showactive'] ? true : false,
                //SUB THUMBNAILS
                'variation_thumbnails' => ($this->options['variation_thumbnails'] ? true : false),
                'columns_variations' => $this->options['columns_variations'],
                'variation_thumbnails_validate' => $this->options['variation_thumbnails_validate'],
            );
        } else {
            if ($detect->isMobile()) {
                $this->options['lens'] = false;
            }

            return array(
                'version' => SVI_VERSION,
                'rtl' => is_rtl(),
                'template' => $this->theme->template,
                'flatsome' => $this->theme->template == 'flatsome' ? 'has-hover' : false,
                //LENS
                'lens' => ($this->options['lens'] ? true : false),
                'lens_containlenszoom' => true,
                'lens_mobiledisabled' => $this->options['lens_mobiledisabled'],
                //LIGTHBOX
                'lightbox' => $this->options['lightbox'] ? true : false,
                'variation_thumbnails_lb' => $this->options['variation_thumbnails_lb'] ? true : false,
                'lightbox_enabled' => 'main',
                'lightbox_icon' => $this->options['lightbox_icon'] ? true : false,
                'lightbox_share' => $this->options['lightbox_share'] ? true : false,
                'lightbox_close' => $this->options['lightbox_close'] ? true : false,
                'lightbox_controls' => $this->options['lightbox_controls'] ? true : false,
                'lightbox_zoom' => $this->options['lightbox_zoom'] ? true : false,
                'lightbox_counter' => $this->options['lightbox_counter'] ? true : false,
                'lightbox_fullScreen' => $this->options['lightbox_fullScreen'] ? true : false,
                //THUMBNAILS
                'columns' => $this->options['columns'],
                'hidden_thumb' => $this->options['hide_thumbs'] ? true : false,
                //SUB THUMBNAILS
                'variation_thumbnails' => ($this->options['variation_thumbnails'] ? true : false),
                'columns_variations' => $this->options['columns_variations'],
            );
        }
    }

    public function parseData($pid = false)
    {
        global $post;

        if ($pid) {
            $product = wc_get_product($pid);
        } else {
            $pid = $post->ID;
            $product = wc_get_product($post->ID);
        }

        if (!$product) {
            return array();
        }

        $images = apply_filters('svi_gallery_images', $this->getImages($product, $pid));

        return array(
            'type' => !$product->is_type('variable') ? true : false,
            'images' => (object) $images,
            'woosvislug' => empty($images) ? '' : $this->prepInformation($product), //LOADS ALL THE VARIATIONS
        );
    }

    public function load_scripts()
    {
        $wp_scripts = wp_scripts();
        //echo "<pre>".print_r($wp_scripts->registered,true)."</pre>";
        if (!current_theme_supports('wc-product-gallery-lightbox')) {
            if ($this->options['lightbox']) {
                $handle = 'photoswipe' . $this->suffix . '.js';
                $list = 'enqueued';
                if (!wp_script_is($handle, $list)) {
                    wp_enqueue_script('svi-photoswipe');
                    wp_enqueue_script('svi-photoswipe-ui-default');

                    wp_enqueue_style('svi-photoswipe');
                    wp_enqueue_style('svi-photoswipe-default-skin');
                }
            }
        }

        $data = $this->parseGlobalData();

        if (svi_fs()->can_use_premium_code__premium_only()) {
            if ($data['slider'] || ($this->options['lightbox_thumbnails'] && $this->options['lightbox'])) {
                //ENQUEUE STYLES
                wp_enqueue_style('svi-swiper');
                //ENQUEUE SCRIPTS
                wp_enqueue_script('svi-swiper');
            }
        }

        //ENQUEUE STYLES
        wp_enqueue_style('dashicons');
        wp_enqueue_style('svi-frontend');
        //ENQUEUE SCRIPTS
        if ($this->options['lens']) {
            wp_enqueue_script('svi-ez-plus');
        }

        wp_enqueue_script('svi-frontend');

        //wp_localize_script('svi-frontend', 'wcsviajax', array('call' => WC()->ajax_url()));
        wp_localize_script('svi-frontend', 'wcsvi', (object) array('data' => $data));

    }

    public function render_before_add_to_cart_button()
    {
        echo '<div class="svi-vue-variationthumbs-app">';
        echo '</div>';
    }

    /**
     * Render frontend app
     *
     *
     * @return string
     */
    public function render_frontend()
    {
        global $post;

        if (!isset($post->ID)) {
            return;
        }

        $run = get_post_meta($post->ID, '_checkbox_svipro_enabled', true);

        if ($run == 'yes') {
            return;
        }

        $data = $this->parseGlobalData();

        $columns = $this->options['columns'];

        if (svi_fs()->can_use_premium_code__premium_only()) {
            $attr = array(
                'svi-woocommerce-product-gallery',
                'woocommerce-product-gallery--' . (has_post_thumbnail() ? 'with-images' : 'without-images'),
                'woocommerce-product-gallery--columns-' . absint($columns),
            );

            if (!$data['imgClass']) {
                array_push($attr, 'images');
            }
            if (!empty(trim($data['custom_class']))) {
                $custom = explode(' ', $data['custom_class']);
                foreach ($custom as $class) {
                    array_push($attr, $class);
                }
            }

        } else {
            $attr = array(
                'svi-woocommerce-product-gallery',
                'woocommerce-product-gallery--' . (has_post_thumbnail() ? 'with-images' : 'without-images'),
                'woocommerce-product-gallery--columns-' . absint($columns),
                'images',
            );
        }

        $wrapper_classes = apply_filters('svi_single_product_image_gallery_classes', $attr);

        ?>
            <?php if ($this->theme->template == 'flatsome') {?>
              <?php do_action('flatsome_sale_flash');?>

                <div class="image-tools absolute top show-on-hover right z-3">
                    <?php do_action('flatsome_product_image_tools_top');?>
                </div>
            <?php }?>

            <div class="whitespacesvi">&nbsp;</div>
            <div data-svi="<?php echo htmlspecialchars(json_encode($this->parseData($post->ID)), ENT_QUOTES, 'UTF-8'); ?>" class="<?php echo esc_attr(implode(' ', array_map('sanitize_html_class', $wrapper_classes))); ?>">

            <div class="svi-vue-frontend-app">
                    <div class="sivmainloader">
                        <div class="signal"></div>
                    </div>
                    <?php
if (svi_fs()->can_use_premium_code__premium_only()) {
            if ($data['preload_fimg']) {
                the_post_thumbnail();
            }
        }
        ?>

                </div>
            </div>
        <?php
}

    /**
     * Render frontend sub thumbs
     *
     * @since 1.1.1
     * @return instance object
     */
    public function show_thumb_images()
    {
        $data = $this->parseGlobalData();

    }

/**
 * Runs the fallback
 *
 *
 * @since 1.0.0
 * @return HTML
 */
    public function fallback($pid)
    {

        $return = '';
        $product_image_gallery = array();
        if (metadata_exists('post', $pid, '_product_image_gallery')) {
            $product_image_gallery = explode(',', get_post_meta($pid, '_product_image_gallery', true));
        } else {
            // Backwards compat
            $attachment_ids = get_posts('post_parent=' . $pid . '&numberposts=-1&post_type=attachment&orderby=menu_order&order=ASC&post_mime_type=image&fields=ids&meta_key=_woocommerce_exclude_image&meta_value=0');
            $attachment_ids = array_diff($attachment_ids, array(get_post_thumbnail_id()));
            if ($attachment_ids) {
                $product_image_gallery = explode(',', $attachment_ids);
            }

        }

        if (!is_array($product_image_gallery) || count($product_image_gallery) < 1) {
            return;
        }

        $product_image_gallery = array_filter($product_image_gallery);

        $order = array();

        foreach ($product_image_gallery as $key => $value) {

            $woosvi_slug = get_post_meta($value, 'woosvi_slug_' . $pid, true);

            if (is_array($woosvi_slug)) {

                $data = array();

                foreach ($woosvi_slug as $k => $v) {

                    if (count($v) > 1) {
                        $data[] = implode('_svipro_', $v);
                    } else {
                        $data[] = $v;
                    }
                }

                $woosvi_slug = $data;
            }

            if (!$woosvi_slug) {
                $woosvi_slug = get_post_meta($value, 'woosvi_slug', true);
            }

            if (!$woosvi_slug) {
                $woosvi_slug = 'nullsvi';
            }

            if (is_array($woosvi_slug)) {

                foreach ($woosvi_slug as $k => $v) {

                    if (is_array($v)) {
                        $order[$v[0]][] = $value;
                    } else {
                        $order[$v][] = $value;
                    }

                }
            } else {
                $order[$woosvi_slug][] = $value;
            }
        }

        unset($order['nullsvi']);
        $ordered = array();
        foreach ($order as $k => $v) {

            $arr = array(
                'slugs' => explode('_svipro_', $k),
                'imgs' => $v,
            );

            array_push($ordered, $arr);
        }

        update_post_meta($pid, 'woosvi_slug', $ordered);

    }

    public function prepInformation($product, $idonly = false, $check_pid = null)
    {
        global $post;
        $wpml_slugs = false;
        $post_id = $post->ID;
        if ($check_pid) {
            $post_id = $check_pid;
        }

        $pid = $this->wpml_original($post_id);

        if (class_exists('SitePress')) {
            $wpml_slugs = $this->wpml($post_id, $product, $pid);
        }
        $return = array();
        $woosvi_slug = get_post_meta($pid, 'woosvi_slug', true);

        if (empty($woosvi_slug)) {
            $this->fallback($pid);
            $woosvi_slug = get_post_meta($pid, 'woosvi_slug', true);
        }

        foreach ($woosvi_slug as $k => $v) {
            if ($wpml_slugs) {
                $v['slugs'] = $this->wpml_translate_slug($wpml_slugs, $v['slugs']);
            }

            $v['slugs'] = array_map('trim', $v['slugs']);
            $return[strtolower(implode('_svipro_', $v['slugs']))] = array();
            if ($idonly) {
                $return[strtolower(implode('_svipro_', $v['slugs']))] = $v['imgs'];
            } else {
                foreach ($v['imgs'] as $id) {
                    $return[strtolower(implode('_svipro_', $v['slugs']))]['x' . $id] = array();
                }
            }
        }
        if (array_key_exists('svidefault', $return)) {
            $default_product = get_post_thumbnail_id($pid);
            $return['svidefault'] = array('x' . $default_product => array()) + $return['svidefault'];
        }

        return $return;
    }

    public function getImages($product, $o_pid)
    {

        $pid = $this->wpml_original($o_pid);
        if ($pid != $o_pid) {
            $product = wc_get_product($pid);
        }
        $default_img = get_post_thumbnail_id($pid);
        $attachment_ids = array($default_img);
        // $attachment_ids = array_merge($attachment_ids, $product->get_gallery_image_ids());
        $attachment_ids = array_merge($attachment_ids, explode(',', get_post_meta($pid, '_product_image_gallery', true)));
        $attachment_ids = array_unique($attachment_ids);
        $attachment_ids = array_values(array_filter($attachment_ids));

        $images = array();
        if ($attachment_ids) {
            $x = 0;
            foreach ($attachment_ids as $attachment_id) {
                $img_arr = array(
                    'id' => intval($attachment_id),
                    'product_img' => $default_img == $attachment_id ? true : false,
                    'single' => $this->getMainImage($attachment_id, $this->options['main_imagesize']),
                    'thumb' => $this->getMainImage($attachment_id, $this->options['thumb_imagesize']),
                    'key' => $x,
                );
                array_push($images, $img_arr);
                $x++;
            }
        }

        return $images;
    }

    public function getMainImage($attachment_id = false, $main_image = false)
    {
        global $post;

        if (!$attachment_id) {
            $attachment_id = get_post_thumbnail_id($post->ID);
        }

        $gallery_thumbnail = wc_get_image_size($this->options['thumb_imagesize']);
        $full_size = apply_filters('woocommerce_gallery_full_size', apply_filters('woocommerce_product_thumbnails_large_size', 'full'));
        $thumbnail_size = apply_filters('woocommerce_gallery_thumbnail_size', array($gallery_thumbnail['width'], $gallery_thumbnail['height']));
        $image_size = apply_filters('woocommerce_gallery_image_size', $this->options['main_imagesize'] ? $this->options['main_imagesize'] : $full_size);
        $thumbnail_src = wp_get_attachment_image_src($attachment_id, $this->options['thumb_imagesize']);
        $large_image = wp_get_attachment_image_src($attachment_id, $image_size);
        $image_src = wp_get_attachment_image_src($attachment_id, $main_image ? $main_image : $full_size);
        $image_full = wp_get_attachment_image_src($attachment_id, $full_size);
        $img = $this->imgtagger(
            wp_get_attachment_image(
                $attachment_id, $image_size, false, array(
                    'title' => get_the_title($attachment_id),
                    'data-caption' => wp_get_attachment_caption($attachment_id),
                    'data-src' => $image_src[0],
                    'data-large_image' => $large_image[0],
                    'data-large_image_width' => $large_image[1],
                    'data-large_image_height' => $large_image[2],
                    'data-thumb_image' => $thumbnail_src[0],
                    'data-thumb_image_width' => $thumbnail_src[1],
                    'data-thumb_image_height' => $thumbnail_src[2],
                    'class' => $main_image ? 'wp-post-image' : '',
                )
            )
        );

        $full_img_sizes = array('full_image' => $image_full[0],
            'full_image_width' => $image_full[1],
            'full_image_height' => $image_full[2]);

        $img = array_merge($img, $full_img_sizes);

        return $img;

    }

    /**
     * Break images tags to array to be used
     *
     * @since 1.0.0
     * @return array
     */
    public function imgtagger($fullimg_tag)
    {

        preg_match_all('/(alt|title|src|caption|woosvislug|svizoom-image|srcset|sizes|width|height|class|thumb_image|thumb_image_width|thumb_image_height|large_image|large_image_width|large_image_height)=("[^"]*")/i', $fullimg_tag, $fullimg_split);

        foreach ($fullimg_split[2] as $key => $value) {
            if ($value == '""') {
                $fullimg_split[2][$key] = "";
            } else {
                $fullimg_split[2][$key] = str_replace('"', "", $value);
            }

        }

        return array_combine($fullimg_split[1], $fullimg_split[2]);
    }

    /**
     * Get translated Slugs
     *
     * @since 1.0.0
     * @return array
     */
    public function wpml($pid, $product, $original)
    {
        global $sitepress;

        if (!$product->is_type('variable')) {
            return false;
        }

        $slugs = array();

        $attributes = get_post_meta($pid, '_product_attributes');

        if (!empty($attributes)) {
            foreach ($attributes[0] as $att => $attribute) {

                if ($attribute['is_taxonomy'] && $attribute['is_variation']) {
                    $terms = wp_get_post_terms($pid, esc_attr($att), 'all');

                    foreach ($terms as $tr => $term) {
                        remove_filter('get_term', array($sitepress, 'get_term_adjust_id'), 1, 1);
                        $gtb = get_term(icl_object_id($term->term_id, esc_attr($att), true, $sitepress->get_default_language()));

                        $slugs[strtolower(esc_attr(($gtb->slug)))] = esc_attr($term->slug);
                        add_filter('get_term', array($sitepress, 'get_term_adjust_id'), 1, 1);
                    }
                }
            }
        }
        $attributes_original = get_post_meta($original, '_product_attributes');

        if (!empty($attributes_original)) {
            foreach ($attributes_original[0] as $att => $attribute) {

                if (!$attribute['is_taxonomy'] && $attribute['is_variation']) {

                    if (array_key_exists($att, $attributes[0])) {
                        $values = str_replace(" ", "", $attributes[0][$att]['value']);
                        if (!empty($values)) {
                            $terms = explode('|', $values);

                            $values_original = str_replace(" ", "", $attribute['value']);
                            $terms_original = explode('|', $values_original);

                            foreach ($terms_original as $tr => $term) {
                                $slugs[strtolower(esc_attr($term))] = esc_attr(strtolower($terms[$tr]));
                            }
                        }
                    }
                }
            }
        }
        if (svi_fs()->can_use_premium_code__premium_only()) {
            $slugs['svidefault'] = 'svidefault';
            $slugs['sviproglobal'] = 'sviproglobal';
        }
        return $slugs;
    }

    public function filter_woocommerce_cart_item_thumbnail__premium_only($product_get_image, $cart_item, $cart_item_key)
    {
        if ($cart_item['variation_id'] > 0) {
            $product = wc_get_product($cart_item['product_id']);
            foreach ($cart_item['variation'] as $k => $v) {
                $slugs_confirm[] = strtolower($v);
            }
            if (count($cart_item['variation']) > 1) {
                array_push($slugs_confirm, strtolower(implode('_svipro_', $cart_item['variation'])));
            }

            $data = $this->prepInformation($product, false, $cart_item['product_id']); //LOADS ALL THE VARIATIONS
            foreach ($slugs_confirm as $index => $slug) {
                if (array_key_exists($slug, $data)) {
                    foreach ($data[$slug] as $img_k => $img_data) {
                        $img_id = filter_var($img_k, FILTER_SANITIZE_NUMBER_INT);
                        $image_title = $product->get_title();
                        $product_get_image = wp_get_attachment_image($img_id, apply_filters('single_product_small_thumbnail_size', $this->options['thumb_imagesize']), 0, $attr = array(
                            'title' => $image_title,
                            'alt' => $image_title,
                        ));
                        break;
                    }
                    break;
                }
            }
        }
        return $product_get_image;
    }

    // define the woocommerce_order_item_thumbnail callback
    public function filter_woocommerce_order_item_thumbnail__premium_only($var, $item)
    {
        $product = $item->get_product();
        if ($product->post_type == 'product_variation') {

            $attributes = $product->get_attributes();
            foreach ($attributes as $k => $v) {
                $slugs_confirm[] = strtolower($v);
            }
            if (count($attributes) > 1) {
                array_push($slugs_confirm, strtolower(implode('_svipro_', $attributes)));
            }
            $data = $this->prepInformation($product, false, $product->get_parent_id()); //LOADS ALL THE VARIATIONS
            foreach ($slugs_confirm as $index => $slug) {
                if (array_key_exists($slug, $data)) {
                    foreach ($data[$slug] as $img_k => $img_data) {
                        $img_id = filter_var($img_k, FILTER_SANITIZE_NUMBER_INT);
                        $image_title = $product->get_title();
                        $dom = new \DOMDocument();
                        $dom->loadHTML($var);
                        $var = '<div style="margin-bottom: 5px"><img src="' . ($img_id ? current(wp_get_attachment_image_src($img_id, 'thumbnail')) : wc_placeholder_img_src()) . '" alt="' . esc_attr__('Product image', 'woocommerce') . '" height="' . esc_attr($dom->getElementsByTagName('img')->item(0)->getAttribute('height')) . '" width="' . esc_attr($dom->getElementsByTagName('img')->item(0)->getAttribute('width')) . '" style="vertical-align:middle; margin-' . (is_rtl() ? 'left' : 'right') . ': 10px;" /></div>';

                        break;
                    }
                    break;
                }
            }

        }

        // make filter magic happen here...
        return $var;

    }
    /**
     * Adds product images to the WooCommerce order emails table
     * Uses WooCommerce 2.5 or newer
     *
     * @param string $output the buffered email order items content
     * @param \WC_Order $order
     * @return $output the updated output
     */
    public function filter_add_images_woocommerce_emails__premium_only($args)
    {
        $args['show_image'] = true;
        $args['image_size'] = array(50, 50);
        return $args;
    }

    public function wpml_original($id)
    {
        global $wpdb;
        if (class_exists('SitePress')) {
            $orig_lang_id = $wpdb->get_var("SELECT trans2.element_id FROM {$wpdb->prefix}icl_translations AS trans1 INNER JOIN {$wpdb->prefix}icl_translations AS trans2 ON trans2.trid = trans1.trid WHERE trans1.element_id = " . $id . " AND trans2.source_language_code IS NULL");
            if (is_null($orig_lang_id)) {
                return $id;
            } else {
                return $orig_lang_id;
            }
        } else {
            return $id;
        }

    }

    public function wpml_translate_slug($wpml_slugs, $slugs)
    {
        $return = array();

        foreach ($slugs as $slug) {
            $return[] = array_key_exists($slug, $wpml_slugs) ? $wpml_slugs[$slug] : $slug;
        }
        return $return;
    }

    /**
     * Remove hooks for plugin to work properly
     *
     * @since 1.1.1
     * @return instance object
     */
    public function remove_hooks()
    {

        global $post;

        $run = get_post_meta($post->ID, '_checkbox_svipro_enabled', true);

        if ($run == 'yes') {
            return;
        }

        //if ($this->runsvi) {
        remove_action('woocommerce_before_single_product_summary', 'woocommerce_show_product_images', 10);
        remove_action('woocommerce_before_single_product_summary', 'woocommerce_show_product_images', 20);

        // Mr. Tailor
        remove_action('woocommerce_before_single_product_summary_product_images', 'woocommerce_show_product_images', 20);
        remove_action('woocommerce_product_summary_thumbnails', 'woocommerce_show_product_thumbnails', 20);

        //WOWMALL
        //remove_action('woocommerce_before_single_product_summary', 'wowmall_woocommerce_show_product_images', 20);
        //wp_deregister_script('wowmall-wc-single-product-gallery');
        //wp_deregister_script('single-product-lightbox');

        //Electro support
        remove_action('woocommerce_before_single_product_summary', 'electro_show_product_images', 20);

        //AURUM support
        remove_action('woocommerce_before_single_product_summary', 'aurum_woocommerce_show_product_images', 25);

        // Remove images from Bazar theme
        if (class_exists('YITH_WCMG')) {
            $this->remove_filters_for_anonymous_class('woocommerce_before_single_product_summary', 'YITH_WCMG_Frontend', 'show_product_images', 20);
            $this->remove_filters_for_anonymous_class('woocommerce_product_thumbnails', 'YITH_WCMG_Frontend', 'show_product_thumbnails', 20);
        }
        //}
    }

    /*
     *
     * Helper: Allow to remove method for a hook when it's a class method used
     *
     * @param str $hook_name Name of the wordpress hook
     * @param str $class_name Name of the class where the add_action resides
     * @param str $method_name Name of the method to unhook
     * @param str $priority The priority of which the above method has in the add_action
     *
     */

    public function remove_filters_for_anonymous_class($hook_name = '', $class_name = '', $method_name = '', $priority = 0)
    {

        global $option;

        if (!isset($option[$hook_name][$priority]) || !is_array($option[$hook_name][$priority])) {
            return false;
        }

        foreach ((array) $option[$hook_name][$priority] as $unique_id => $filter_array) {
            if (isset($filter_array['function']) && is_array($filter_array['function'])) {
                if (is_object($filter_array['function'][0]) && get_class($filter_array['function'][0]) && get_class($filter_array['function'][0]) == $class_name && $filter_array['function'][1] == $method_name) {
                    unset($option[$hook_name][$priority][$unique_id]);
                }
            }
        }

        return false;
    }
}
